@@ -177,7 +177,7 @@ public:
     {
     }
 
-    virtual void run()
+    void run() Q_DECL_OVERRIDE
     {
         Solver::ExitStatus result = m_solver->patsolve();
         emit finished( result );
@@ -1052,7 +1052,8 @@ void DealerScene::mousePressEvent( QGraphicsSceneMouseEvent * e )
 {
     stop();
 
-    KCard * card = qgraphicsitem_cast<KCard*>( itemAt( e->scenePos() ) );
+    const QList<QGraphicsItem *> itemsAtPoint = items( e->scenePos() );
+    KCard * card = qgraphicsitem_cast<KCard*>( itemsAtPoint.isEmpty() ? 0 : itemsAtPoint.first() );
 
     if ( m_peekedCard )
     {
