@@ -177,7 +177,7 @@ public:
       : DealerInfo(I18N_NOOP("Golf"), GolfId)
     {}
 
-    virtual DealerScene *createGame() const
+    DealerScene *createGame() const Q_DECL_OVERRIDE
     {
         return new Golf( this );
     }
