@@ -21,7 +21,7 @@
  * -------------------------------------------------------------------------
  *   This program is free software; you can redistribute it and/or
  *   modify it under the terms of the GNU General Public License as
- *   published by the Free Software Foundation; either version 2 of 
+ *   published by the Free Software Foundation; either version 2 of
  *   the License, or (at your option) any later version.
  *
  *   This program is distributed in the hope that it will be useful,
@@ -57,7 +57,7 @@
 
 #include <Kdelibs4ConfigMigrator>
 #include <climits>
-#include <time.h>
+#include <ctime>
 #include <QStandardPaths>
 #include <QApplication>
 #include <QCommandLineParser>
@@ -185,8 +185,6 @@ int main( int argc, char **argv )
     QCommandLineParser parser;
     KAboutData::setApplicationData(aboutData);
     KCrash::initialize();
-    parser.addVersionOption();
-    parser.addHelpOption();
 
     parser.addOption(QCommandLineOption(QStringList() << QStringLiteral("solvegame"), i18n( "Try to find a solution to the given savegame" ), QStringLiteral("file")));
     parser.addOption(QCommandLineOption(QStringList() << QStringLiteral("solve"), i18n("Dealer to solve (debug)" ), QStringLiteral("num")));
@@ -228,7 +226,7 @@ int main( int argc, char **argv )
 
     QString testdir = parser.value(QStringLiteral("testdir"));
     if ( !testdir.isEmpty() ) {
-       qsrand(time(0));
+       qsrand(std::time(nullptr));
        if ( parser.isSet(QStringLiteral("generate")) ) {
           for (int dealer = 0; dealer < 20; dealer++) {
               DealerScene *f = getDealer( dealer );
@@ -260,7 +258,7 @@ int main( int argc, char **argv )
                 }
              }
           }
-       } 
+       }
        return 0;
     }
 
@@ -311,7 +309,7 @@ int main( int argc, char **argv )
     }
 
     QString gametype = parser.value(QStringLiteral("gametype")).toLower();
-    QFile savedState( QStandardPaths::writableLocation(QStandardPaths::DataLocation) + QLatin1Char('/') + saved_state_file) ;
+    QFile savedState( QStandardPaths::writableLocation(QStandardPaths::AppDataLocation) + QLatin1Char('/') + saved_state_file);
 
     MainWindow *w = new MainWindow;
     if (parser.positionalArguments().count())
@@ -335,6 +333,6 @@ int main( int argc, char **argv )
     w->show();
 
     const KDBusService dbusService(KDBusService::Multiple);
-    
+
     return app.exec();
 }
