@@ -25,16 +25,16 @@ class Idiot;
 class IdiotSolver : public Solver
 {
 public:
-    IdiotSolver(const Idiot *dealer);
-    virtual int get_possible_moves(int *a, int *numout);
-    virtual bool isWon();
-    virtual void make_move(MOVE *m);
-    virtual void undo_move(MOVE *m);
-    virtual int getOuts();
-    virtual void translate_layout();
-    virtual MoveHint translateMove(const MOVE &m);
+    explicit IdiotSolver(const Idiot *dealer);
+    int get_possible_moves(int *a, int *numout) Q_DECL_OVERRIDE;
+    bool isWon() Q_DECL_OVERRIDE;
+    void make_move(MOVE *m) Q_DECL_OVERRIDE;
+    void undo_move(MOVE *m) Q_DECL_OVERRIDE;
+    int getOuts() Q_DECL_OVERRIDE;
+    void translate_layout() Q_DECL_OVERRIDE;
+    MoveHint translateMove(const MOVE &m) Q_DECL_OVERRIDE;
 
-    virtual void print_layout();
+    void print_layout() Q_DECL_OVERRIDE;
 
     bool canMoveAway( int pile ) const;
 
