@@ -20,7 +20,7 @@
 
 #include <QDebug>
 
-#include <QtCore/QtGlobal>
+#include <QtGlobal>
 
 #include <cstdlib>
 #include <cstring>
